<?php
/**
 *Eblog Lite List View
 */
class Eblog_Lite_Slider_Section extends WP_Widget {

	/* Register Widget with WordPress*/
	function __construct() {
		parent::__construct(
			'eblog_lite_blog_slider_section', // Base ID
			esc_html__( 'eBlog Lite: Slider Section', 'eblog-lite' ), //Widget Name
			array( 'description' => esc_html__( 'Display the post slider.', 'eblog-lite' ), ) // Args
		);
	}
	/**
     * Widget Form Section
     */
	public function form( $instance ) {
		$defaults = array(
            'category'		=> 'all',
			'number_posts'	=> 6,
		);
		$instance = wp_parse_args( (array) $instance, $defaults );

	?>
		<p>
			<label><?php esc_html_e( 'Select a post category:', 'eblog-lite' ); ?></label>
			<?php wp_dropdown_categories( array( 'name' => $this->get_field_name('category'), 'selected' => $instance['category'], 'show_option_all' => 'Show all posts', 'class' => 'widefat' ) ); ?>
		</p>
		<p>
			<label for="<?php echo $this->get_field_id( 'number_posts' ); ?>"><?php esc_html_e( 'Number of posts:', 'eblog-lite' ); ?></label>
			<input class="widefat" type="number" id="<?php echo $this->get_field_id( 'number_posts' ); ?>" name="<?php echo $this->get_field_name( 'number_posts' );?>" value="<?php echo absint( $instance['number_posts'] ); ?>" size="3"/> 
		</p>
					
	<?php

	}

    /**
     * Post Update 
     */
	public function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance[ 'category' ]	= absint( $new_instance[ 'category' ] );
		$instance[ 'number_posts' ] = (int)$new_instance[ 'number_posts' ];
		return $instance;
	}

    /**
     * Front End Display
     */
	public function widget( $args, $instance ) {
		extract($args);

		$eblog_lite_cat_id = ( ! empty( $instance['category'] ) ) ? absint( $instance['category'] ) : '';
		$eblog_lite_post_cunt = ( ! empty( $instance['number_posts'] ) ) ? absint( $instance['number_posts'] ) : 6; 
        // Latest Posts
        if( !empty($eblog_lite_title) ){
            $eblog_list_title_filter = $eblog_lite_title;
            $eblog_lite_grid_title_link = get_category_link($eblog_lite_cat_id);
        }else{
            $eblog_lite_grid_title_link = get_category_link($eblog_lite_cat_id);
            $eblog_list_title_filter = get_cat_name($eblog_lite_cat_id);
        }

	?>
        <section class="homepage-slider-section"> 
			<div id="eblog_lite_main_slider" class="owl-carousel owl-theme center-owl-nav">
                <?php 
                    $args = array('post_type'=>'post','posts_per_page'=>$eblog_lite_post_cunt,'cat'=>$eblog_lite_cat_id);
                    $blog_query = new WP_Query( $args ); 
                    
                    while($blog_query->have_posts()): $blog_query->the_post(); 
					if( has_post_thumbnail() ):
                ?>
                <!-- post slider loop stat -->
					<article class="article thumb-article">
						<div class="article-img">
							<?php the_post_thumbnail('eblog-lite-thumbnail-slider'); ?>
						</div>
						<div class="article-body">
							<?php the_category(); ?>
							<h2 class="article-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h2>
							<ul class="article-meta">
								<li><i class="fa fa-clock-o"></i><?php the_time(get_option('date_format' )); ?></li>
								<li><?php  echo getPostViews( get_the_ID() ); ?></li>
								<li><i class="fa fa-comments"></i> <?php printf( esc_html( _n( '%d Comment', '%d Comments', get_comments_number(), 'eblog-lite'  ) ), esc_html(number_format_i18n(get_comments_number()))); ?></li>
							</ul>
						</div>
					</article>
                <?php endif; endwhile; ?>
            </div>
        </section>
	<?php
		echo $after_widget;
	}
}
// Register The Category Posts
function eblog_lite_slider_section_config() {
    register_widget( 'Eblog_Lite_Slider_Section' );
}
add_action( 'widgets_init', 'eblog_lite_slider_section_config' );